@@ -1,5 +1,7 @@
 extractRules <-
-function(treeList,X,ntree=100,maxdepth=6,random=FALSE){
+function(treeList,X,ntree=100,maxdepth=6,random=FALSE,digits=NULL){
+ if(is.numeric(digits)) digits <- as.integer(abs(digits))
+ 
  levelX = list()
  for(iX in 1:ncol(X))
  levelX <- c(levelX,list(levels(X[,iX])))
@@ -12,8 +14,9 @@ function(treeList,X,ntree=100,maxdepth=6,random=FALSE){
  rule = list(); count = 0; rowIx = 1; 
  # tree = getTree(rf,iTree,labelVar=FALSE)
  tree <- treeList$list[[iTree]]
+ if(nrow(tree)<=1) next # skip if there is no split
  ruleSet = vector("list", length(which(tree[,"status"]==-1)))
- res = treeVisit(tree,rowIx = rowIx,count,ruleSet,rule,levelX,length=0,max_length=max_length)
+ res = treeVisit(tree,rowIx = rowIx,count,ruleSet,rule,levelX,length=0,max_length=max_length,digits=digits)
  allRulesList = c(allRulesList, res$ruleSet)
  }
 allRulesList <- allRulesList[!unlist(lapply(allRulesList, is.null))]
